@@ -129,10 +129,10 @@ class CustomDatasetV2(CustomDataset):
         self.patch_size = np.array(patch_size)
         self.transform = transform
         self.batch_size = batch_size
-        super().__init__(root_dir, device = None, normalizer = None, mode = 'train', dim = '3d', correct_direction = False, resample = None)
+        super().__init__(root_dir, device = device, normalizer = normalizer, mode = mode, dim = dim, correct_direction = correct_direction, resample = resample)
     
     def __len__(self):
-        return super.__len__()
+        return super().__len__()
     
     def set_direction(self, img, direction):
         return super().set_direction(img, direction)
@@ -306,7 +306,7 @@ class CustomDatasetV2(CustomDataset):
             result_seg = result_seg.to(self.device)
 
         if self.transform:
-            result_images, result_seg = self.transform(result_images, result_seg, info_data)
+            result_images, result_seg = self.transform(result_images.to(self.device), result_seg.to(self.device), info_data)
         
 
         return result_images, result_seg.long()
