@@ -112,8 +112,6 @@ class Trainer(object):
                     output = self.model(images)
                     self.optimizer.zero_grad()
                     loss = self.calculate_loss(output, seg, writer, e)
-                    if self.tr_dl.current_index == 0:
-                        deep_supervision_visualization(output, seg)
                     loss.backward()
                     self.optimizer.step()
 
